# # import csv
# import random
# # from time import sleep
# from locust import HttpUser, SequentialTaskSet, task, constant_pacing
# from locust_plugins.csvreader import CSVReader
# # import os
# # import re
# import time
# from selenium import webdriver
# from selenium.webdriver.chrome.options import Options
# from selenium.webdriver.chrome.service import Service
# from selenium.webdriver.common.by import By
#
# service_obj = Service("C:\\msedgedriver.exe")
# chrome_options = Options()
# chrome_options.add_experimental_option("detach", True)
# driver = webdriver.Chrome(service=service_obj, options=chrome_options)
#
#
# def roleMember():
#     driver.implicitly_wait(10)
#     try:
#         a = driver.find_element(By.XPATH, "//span[contains(text(),'is answering this question.')]")
#         assert a.text == a.text
#     except:
#         print("Team Member answering the question Hint text message not displayed")
#
#     answered_text = driver.find_element(By.XPATH, "//span[contains(text(),'Answered')]")
#     if answered_text.is_displayed():
#         driver.find_element(By.XPATH,
#                             "/html/body/div/main/app-play-panel/section[1]/div/app-quiz/app-play/div/div/div[2]/div[1]/app-quiz-current-card/div/div[2]/div[2]/button[2]").click()
#
#     driver.find_element(By.XPATH,
#                         "/html/body/div/main/app-play-panel/section[1]/div/app-quiz/app-play/div/div/div[1]/app-header-nav/div/div/div[3]/div/a[2]").click()
#     time.sleep(3)
#     driver.find_element(By.XPATH,
#                         "/html/body/div/main/app-play-panel/section[1]/div/app-quiz/app-play/div/div/div[2]/app-quiz-status/div/div/div[3]/button").click()
#     time.sleep(2)
#     driver.find_element(By.XPATH,
#                         "/html/body/div/main/app-play-panel/section[1]/div/app-quiz/app-play/div/div/div[2]/app-quiz-status/div[3]/div/button[2]").click()
#
#
# def rolePlayer():
#     Total_questions = driver.find_elements(By.XPATH, "//div[@class='wrapper']/span")
#
#     for question in Total_questions:
#         print(question.text)
#
#         option = random.randint(1, 5)
#
#         if driver.find_element(By.XPATH, "//span[@class='navigation_btn ng-star-inserted active']"):
#             driver.find_element(By.XPATH, "//div[@class='answers']/div/div/div[1]/div/label[option]").click()
#             driver.find_element(By.XPATH, "//button[contains(text(),'Submit')]").click()
#         else:
#             print("not found")



import csv
import random
from itertools import cycle
from time import sleep
import timeit, trace, webbrowser, base64, re, threading, test
from locust_plugins.csvreader import CSVReader


def LoginUser(self, email, password, environment, generateCSV):
    """This function will log in the user and create a CSV file with status records!
    Pass the email, password, environment (1 for Prod, 2 for Dev2, 3 for Beta, 4 for Dev1)
    and pass 1 for True and 0 for False in generateCSV, 1 will generate the CSV file."""

    # login
    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "https://dev1.d2c.pw"
    else:
        envURL = "https://unstop.com"

    for i in range(0, 10):
        response = self.client.post(url=envURL + '/api/user/login', name='user/login ~ time-' + str(i),
                                    timeout=120, allow_redirects=False,
                                    headers={'accept': 'application/json, text/plain, */*',
                                             'accept-encoding': 'gzip, deflate, br',
                                             'accept-language': 'en-US,en;q=0.9', 'cache-control': 'no-cache',
                                             'content-length': '235', 'content-type': 'application/json'},
                                    json={'grant_type': 'password', 'client_id': 2,
                                          'client_secret': 'JhtzMjAQQkd4hZVLslDOfDEkw6hSQytblrIjQBUd',
                                          'username': email, 'email': email,
                                          'password': password, 'scope': '*', 'network': '', 'access_token': '',
                                          })
        if "access_token" in response.text:
            loginData = response.json()
            # global access_token
            access_token = loginData["access_token"]
            user_email = loginData["email"]
            status = "Logged In"

            if generateCSV == 1:
                # CSV generation with status and email
                with open("/mnt/locust/user_login_status.csv", "a") as csvfile:
                    fieldnames = ['email', 'status']
                    writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
                    # writer.writeheader()
                    writer.writerow({
                        "email": user_email,
                        "status": status
                    })
                    sleep(15)
            else:
                sleep(10)

            return access_token
        elif "user_id" in response.text:
            revokeData = response.json()["data"]
            for t in range(0, 10):
                sleep(5)
                activeRevoke = self.client.post(url=envURL + '/api/user/revoke-active-session',
                                                name='revoke-active-session', timeout=120,
                                                allow_redirects=False,
                                                headers={'accept': 'application/json, text/plain, */*',
                                                         'accept-encoding': 'gzip, deflate, br',
                                                         'accept-language': 'en-US,en;q=0.9',
                                                         'content-length': '250',
                                                         'content-type': 'application/json'},
                                                json=[
                                                    revokeData[0]["id"], revokeData[1]["id"], revokeData[2]["id"]])
                sleep(5)
                if "Sessions revoked successfully" in activeRevoke.text:

                    if generateCSV == 1:
                        # CSV generation with status and email
                        status = "Revoked Login"
                        user_email = email

                        with open("/mnt/locust/user_login_status.csv", "a") as csvfile:
                            fieldnames = ['email', 'status']
                            writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
                            # writer.writeheader()
                            writer.writerow({
                                "email": user_email,
                                "status": status
                            })
                            sleep(10)
                    else:
                        sleep(10)
                    break
                elif t == 9:
                    if generateCSV == 1:
                        # CSV generation with status and email
                        status = "Revoked Failed permanently" + activeRevoke.text
                        user_email = email

                        with open("/mnt/locust/user_login_status.csv", "a") as csvfile:
                            fieldnames = ['email', 'status']
                            writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
                            # writer.writeheader()
                            writer.writerow({
                                "email": user_email,
                                "status": status
                            })
                            sleep(10)
                    else:
                        sleep(2)
                    print("test failed permanently at revoke session" + " time-" + str(t), "\n",
                          activeRevoke.text, email)
                    return "Revoke Failed"
                else:
                    print("test failed to revoke active session" + " time-" + str(t), activeRevoke.text, email)
                    sleep(5)
        elif i == 9:

            if generateCSV == 1:
                # CSV generation with status and email
                status = "Login Failed" + response.text
                user_email = email

                with open("/mnt/locust/user_login_status.csv", "a") as csvfile:
                    fieldnames = ['email', 'status']
                    writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
                    # writer.writeheader()
                    writer.writerow({
                        "email": user_email,
                        "status": status
                    })
                    sleep(10)
            else:
                sleep(10)
            print("Test Failed permanently at login" + " time=" + str(i), response.text, email)
            return "Login Failed"
        else:
            print("login failed" + " time=" + str(i), response.text, email)
            sleep(5)


def LogoutFromAll(self, access_token, environment):
    """ This function will log out the user from all the devices!
    Pass the access_token, and environment (1 for Prod, 2 for Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    # logout from all
    for i in range(0, 10):
        response = self.client.get(url=envURL + '/api/logout-from-all-devices?type=all',
                                   name='logout-from-all-devices?type=all', timeout=120,
                                   allow_redirects=False,
                                   headers={'Accept': 'application/json, text/plain, */*',
                                            'Authorization': 'Bearer ' + access_token})
        if response.status_code == 200:
            return True
        elif i == 9:
            return "Logout from all Failed"
        else:
            print("logout from all failed" + " time-" + str(i), response.text)
            sleep(5)


def DummyUser(TestType):
    """This function will give a dummy user email. Pass TestType, i.e., 1 for AWS testing, else 0. Does not work
    correctly as of now!"""

    if TestType == 1:
        file = "/mnt/locust/file0.csv"
        email_reader = CSVReader(file)
        csvemail = next(email_reader)
        return csvemail[0]
    elif TestType == 0:
        file = "/Users/parasgupta/Downloads/emails_for_dummy2.csv"
        email_reader = CSVReader(file)
        csvemail = next(email_reader)
        return csvemail[0]


def UserWatchList(self, access_token, environment):
    """ This function will get the watchlist of the user! Pass the access_token, and environment (1 for Prod, 2 for
    Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    for i in range(0, 10):
        watchRes = self.client.get(url=envURL + '/api/getMyWatchlist',
                                   name='getMyWatchlist', timeout=120, allow_redirects=False,
                                   headers={'Accept': 'application/json, text/plain, */*',
                                            'Authorization': 'Bearer ' + access_token})
        if "data" in watchRes.text:
            sleep(5)
            return True
        elif i == 9:
            print("Test Failed permanently at watchlist" + " time=" + str(i), watchRes.text)
            sleep(99999999999999999)
        else:
            print("watchlist failed" + " time=" + str(i), watchRes.text)
            sleep(3)


def UserUpcomingRegistered(self, access_token, environment):
    """ This function will get the watchlist of the user! Pass the access_token, and environment (1 for Prod, 2 for
    Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    for i in range(0, 10):
        UpcomingRes = self.client.get(url=envURL + '/api/personalize/upcoming-registered',
                                      name='UpcomingResgistrations', timeout=120, allow_redirects=False,
                                      headers={'Accept': 'application/json, text/plain, */*',
                                               'Authorization': 'Bearer ' + access_token})
        if "data" in UpcomingRes.text:
            sleep(5)
            return True
        elif i == 9:
            print("Test Failed permanently at upcoming registered" + " time=" + str(i), UpcomingRes.text)
            sleep(99999999999999999)
        else:
            print("upcoming registered failed" + " time=" + str(i), UpcomingRes.text)
            sleep(3)


def UserCoins(self, access_token, environment):
    """ This function will get the coins of the user! Pass the access_token, and environment (1 for Prod, 2 for
    Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    for i in range(0, 10):
        coinRes = self.client.get(url=envURL + '/api/get-user-coins',
                                  name='get-user-coins', timeout=120, allow_redirects=False,
                                  headers={'Accept': 'application/json, text/plain, */*',
                                           'Authorization': 'Bearer ' + access_token})
        if "coins" in coinRes.text:
            sleep(5)
            return True
        elif i == 9:
            print("Test Failed permanently ar user coins" + " time=" + str(i), coinRes.text)
            sleep(99999999999999999)
        else:
            print("coins failed" + " time=" + str(i), coinRes.text)
            sleep(3)


def UserPermissions(self, access_token, environment):
    """ This function will get the permissions of the user! Pass the access_token, and environment (1 for Prod, 2 for
    Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    for i in range(0, 10):
        permissionRes = self.client.get(url=envURL + '/api/getUserPermissions',
                                        name='getUserPermissions', timeout=120, allow_redirects=False,
                                        headers={'Accept': 'application/json, text/plain, */*',
                                                 'Authorization': 'Bearer ' + access_token})
        if "data" in permissionRes.text:
            sleep(5)
            return True
        elif i == 9:
            print("Test Failed permanently at user permissions" + " time=" + str(i), permissionRes.text)
            sleep(99999999999999999)
        else:
            print("user permissions failed" + " time=" + str(i), permissionRes.text)
            sleep(3)


def UserAccounts(self, access_token, environment):
    """ This function will get the accounts of the user! Pass the access_token, and environment (1 for Prod, 2 for
    Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    for i in range(0, 10):
        accountRes = self.client.get(url=envURL + '/api/my-all-accounts',
                                     name='my-all-accounts', timeout=120, allow_redirects=False,
                                     headers={'Accept': 'application/json, text/plain, */*',
                                              'Authorization': 'Bearer ' + access_token})
        if "data" in accountRes.text:
            sleep(3)
            return True
        elif i == 9:
            print("Test Failed permanently at all accounts" + " time=" + str(i), accountRes.text)
            sleep(9999999999999999999999)
        else:
            print("all accounts failed" + " time=" + str(i), accountRes.text)
            sleep(3)

# def get_user(TestType):
#     for i in range(0, 9000000000):
#         if TestType == 1:
#             file = "/mnt/locust/file0.csv"
#             email_reader = CSVReader(file)
#             csvemail1 = next(email_reader)
#             csvemail2 = next(email_reader)
#             csvemail3 = next(email_reader)
#             return [csvemail1, csvemail2, csvemail3]
#         elif TestType == 0:
#             file = "/Users/parasgupta/Downloads/emails_for_dummy2.csv"
#             email_reader = CSVReader(file)
#             emails = next(email_reader)
#             csvemail2 = next(email_reader)
#             csvemail3 = next(email_reader)
#             csvemailList = [csvemail1, csvemail2, csvemail3]
#             i += 1
#             return csvemailList, i



import csv
import random
from time import sleep
import timeit, trace, webbrowser, base64, re, threading, test
from locust_plugins.csvreader import CSVReader


def RandomQuizAnswer():
    """This function will randomly return one option from A, B, C, D"""
    ranAnswer = random.choice(["A", "B", "C", "D"])
    return ranAnswer


def QuizReview(self, access_token, quiz_id, review, environment):
    """This function will submit quiz review. Pass the access_token, quiz_id, review message as str,  and environment
    (1 for Prod, 2 for Dev2, 3 for Beta, 4 for Dev1)"""
    # submit quiz review

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    rating = random.randint(1, 6)

    for i in range(0, 10):
        qRevRes = self.client.post(url=envURL + '/api/v2/quiz/' + str(quiz_id) + '/update-review',
                                   name='36.update-review', timeout=120, allow_redirects=False,
                                   headers={'Accept': 'application/json, text/plain, */*',
                                            'Authorization': 'Bearer ' + access_token},
                                   json={'review': review, 'rating': rating})
        # print(qRevRes.text)
        if "successs" in qRevRes.text:
            sleep(random.randint(10, 20))
            break
        elif i == 9:
            print("Test Failed permanently at quiz review" + ' time-' + str(i), "\n", qRevRes.text)
            sleep(99999999999999999)
        else:
            print("Test Failed at quiz review" + ' time-' + str(i), qRevRes.text)
            sleep(3)


def QuizFinish(self, access_token, quiz_id, environment):
    """This function will finish the quiz. Pass the access_token, quiz_id and environment (1 for Prod, 2 for Dev2, 3 for
        Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    # finish the quiz
    for i in range(0, 10):
        finResponse = self.client.post(url=envURL + '/api/v2/quiz/' + str(quiz_id) + '/finish',
                                       name='35.finish', timeout=120, allow_redirects=False,
                                       headers={'Accept': 'application/json, text/plain, */*',
                                                'Authorization': 'Bearer ' + access_token},
                                       json={'finish_type': 'finishBtn', 'is_demo': False})
        # print(finResponse.text)
        if "data" in finResponse.text:
            sleep(random.randint(10, 20))
            return True
        elif i == 9:
            print("Test Failed permanently at quiz Finish" + ' time-' + str(i), "\n", finResponse.text)
            sleep(99999999999999999)
        else:
            print("Test Failed at quiz finish" + ' time-' + str(i), finResponse.text)
            sleep(3)



import random
from time import sleep


def DiscussionPost(self, access_token, comment, environment):
    """This function will post a new discussion for the user. Pass the comment i.e., message to be
    posted to the discussion, access_token, and environment (1 for Prod, 2 for Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    # posting a discussions
    # sleep(random.randint(5, 10))
    for i in range(0, 10):
        disRes = self.client.post(url=envURL + '/api/competition/50340/discussions',
                                  name='12.submit discussion ~ time=' + str(i), timeout=120,
                                  allow_redirects=False, headers={'Accept': 'application/json, text/plain, */*',
                                                                  'Authorization': 'Bearer ' + access_token},
                                  json={'newDiscussion': {'title': comment}, 'page': 1, 'perPage': 6})
        # print(response.text)
        if "data" in disRes.text:
            sleep(random.randint(10, 20))
            break
        elif i == 9:
            print("Test Failed permanently at discussions" + ' time-' + str(i), disRes.text)
            return "Failed"
        else:
            print("Test Failed at discussions" + ' time-' + str(i), disRes.text)
            sleep(5)


def OpportunityReview(self, access_token, review, environment):
    """This function will post a new opportunity review for the user. Pass the review message i.e., message to be
        posted to the review, access_token, and environment (1 for Prod, 2 for Dev2, 3 for Beta, 4 for Dev1)"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    rating = random.randint(1, 6)

    for i in range(0, 10):
        revRes = self.client.post(url=envURL + '/api/competition/50340/reviews',
                                  name='submit reviews', timeout=120,
                                  allow_redirects=False, headers={'Accept': 'application/json, text/plain, */*',
                                                                  'Authorization': 'Bearer ' + access_token},
                                  json={'rating': rating, 'title': '', 'feedback': review,
                                        'user': None})
        # print(response.text)
        if "data" in revRes.text:
            sleep(random.randint(10, 20))
            break
        elif i == 9:
            print("Test Failed permanently at opp review" + ' time-' + str(i), "\n", revRes.text)
            sleep(99999999999999999)
        else:
            print("Test Failed at review" + ' time-' + str(i), revRes.text)
            sleep(3)


def RegisterationNormal(self, access_token, environment, mobile, userEmail, compIds, returnValue):
    """This function will perform normal individual registration for the user. Pass the access_token, environment
    (1 for Prod, 2 for Dev2, 3 for Beta, 4 for Dev1), mobile, userEmail, compIds in "ARRAY", returnValue
    ("1" for getting compete data, 0 for no data)!"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    alphaChoice = ["A", "B", "C", "D", "E", "F", "G", "H"]
    name = "DumPlay" + random.choice(alphaChoice) + str(random.randint(10000, 999999))

    null = ""
    true = True
    false = False

    for i in range(0, 10):
        regResponse = self.client.post(url=envURL + '/api/competition/registration',
                                       name='registration',
                                       timeout=120,
                                       allow_redirects=False, headers={'authorization': 'Bearer ' + access_token,
                                                                       'Accept': 'application/json, text/plain, '
                                                                                 '*/*'},
                                       json={"team": {"name": name, "subscription": 0,
                                                      "players": [{"id": 0, "name": "dummy",
                                                                   "mobile": mobile,
                                                                   "email": userEmail,
                                                                   "organisationName": "S.C.B. Medical College, Cuttack",
                                                                   "others": null,
                                                                   "others_gender": null,
                                                                   "others_course_specialization": "",
                                                                   "organisation": {"id": 145665,
                                                                                    "name": "S.C.B. Medical College, "
                                                                                            "Cuttack",
                                                                                    "logo": null, "logoUrl": "",
                                                                                    "logoUrl2": "",
                                                                                    "public_url": "c/scb-medical"
                                                                                                  "-college-cuttack"
                                                                                                  "-placement-"
                                                                                                  "interview-"
                                                                                                  "competitions"
                                                                                                  "-articles- "
                                                                                                  "videos-145665"}
                                                                      , "player_type": 1, "gender": "M",
                                                                   "location": "India", "differently_abled": 0,
                                                                   "errors": {"nameErrorStatus": false,
                                                                              "nameErrorMsg": "",
                                                                              "emailErrorStatus": false,
                                                                              "emailErrorMsg": "",
                                                                              "mobileErrorStatus": false,
                                                                              "mobileErrorMsg": "",
                                                                              "locationErrorStatus": false,
                                                                              "locationErrorMsg": "",
                                                                              "organisationNameErrorStatus": false,
                                                                              "organisationNameErrorMsg": "",
                                                                              "user_typeErrorStatus": false,
                                                                              "user_typeErrorMsg": "",
                                                                              "study_yearErrorStatus": false,
                                                                              "course_programmeErrorMsg": "",
                                                                              "course_durationErrorMsg": "",
                                                                              "study_yearErrorMsg": "",
                                                                              "course_programmeErrorStatus": false,
                                                                              "course_durationErrorStatus": false,
                                                                              "passing_out_yearErrorStatus": false,
                                                                              "passing_out_yearErrorMsg": "",
                                                                              "work_experienceErrorStatus": false,
                                                                              "work_experienceErrorMsg": "",
                                                                              "course_pursuingErrorStatus": false,
                                                                              "course_pursuingErrorMsg": "",
                                                                              "course_streamErrorStatus": false,
                                                                              "course_streamErrorMsg": "",
                                                                              "course_specializationErrorStatus": false,
                                                                              "course_specializationErrorMsg": "",
                                                                              "differently_abledErrorStatus": false,
                                                                              "differently_abledErrorMsg": "",
                                                                              "genderErrorStatus": false,
                                                                              "school_yearErrorStatus": false},
                                                                   "formValidStatus": true, "formValidMsg": "",
                                                                   "noGender": true, "user_type": 5,
                                                                   "course_pursuing": null, "course_stream": null,
                                                                   "course_specialization": null,
                                                                   "study_year": null, "passing_out_year": 2022,
                                                                   "course_programme": null,
                                                                   "course_duration": null, "work_experience": null}],
                                                      "formValidStatus": true, "formValidMsg": ""}
                                           , "competitionIds": compIds, "method": "new-team", "subscription": 0,
                                             "invitedPlayers": [], "invites_allowed": 0})
        # print(regResponse.text)
        regRes = regResponse.json()["data"]
        if "status" in regResponse.text:
            if returnValue == 1:
                return regRes
            else:
                return True
        elif i == 9:
            print("Test Failed permanently at registration" + ' time-' + str(i), regRes.text)
            return "Failed"
        else:
            print("Test Failed at registration" + ' time-' + str(i), regRes.text)
            sleep(5)


def RandomTeamName():
    """This will generate a random team name for the given team"""

    alphaChoice = ["A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "Q", "R", "S",
                   "T", "U", "V", "W", "X", "Y", "Z"]
    teamname = "Team" + random.choice(alphaChoice) + random.choice(alphaChoice) + str(random.randint(1, 9999))
    return teamname


def RandomPlayerName():
    """This will generate a random player name for the given team"""
    alphaChoice = ["A", "B", "C", "D", "E", "F", "G", "H", "I", "J", "K", "L", "M", "Q", "R", "S",
                   "T", "U", "V", "W", "X", "Y", "Z"]
    playername = "Player" + random.choice(alphaChoice) + random.choice(alphaChoice) + str(random.randint(1, 9999))
    return playername


def RandomMobile():
    """This will generate a random mobile number"""
    ext = random.randint(10000000, 99999999)
    mobile = "+9199" + str(ext)
    return mobile


def RandomGender():
    """This will generate a random gender from the available list"""
    GenderList = ['M', 'F', 'I', 'O', 'NB', 'T']
    Gender = random.choice(GenderList)
    return Gender



def RandomOrganization():
    """This will generate a random organization for the player"""
    OrganizationList = [
        {"id": 483, "name": "Guru Gobind Singh Indraprastha University (GGSIPU), Delhi"},
        {"id": 591, "name": "Indian Institute of Management (IIM), Ranchi"},
        {"id": 597, "name": "Indian Institute of Management (IIM), Udaipur"},
        {"id": 122804, "name": "Global Institutes of Management (GIM), Amritsar"},
        {"id": 614, "name": "Indian Institute of Technology (IIT), Indore"},
        {"id": 122804, "name": "Global Institutes of Management (GIM), Amritsar"},
        {"id": 604, "name": "Indian Institute of Technology (IIT), Bombay"},
        {"id": 608, "name": "Indian Institute of Technology (IIT),  Roorkee"},
        {"id": 597, "name": "Indian Institute of Management (IIM), Udaipur"},
        {"id": 122804, "name": "Global Institutes of Management (GIM), Amritsar"}]

    organization = random.choice(OrganizationList)
    return organization


def ExploreFlow(self, environment, compIds):
    """This will be user's explore flow. Pass the access_token, environment
        (1 for Prod, 2 for Dev2, 3 for Beta, 4 for Dev1), compId!"""

    if environment == 1:
        envURL = "https://unstop.com"
    elif environment == 2:
        envURL = "https://dev2.dare2compete.com"
    elif environment == 3:
        envURL = "https://beta.dare2compete.com"
    elif environment == 4:
        envURL = "http://dev1.d2c.pw/"
    else:
        envURL = "https://unstop.com"

    # competitions api
    for z in range(0, 5):
        compRes = self.client.get(url=envURL + '/api/public/competition/' + str(compIds[0]),
                                  name='competition/' + str(compIds[0]), timeout=120,
                                  allow_redirects=False,
                                  headers={'Accept': 'application/json, text/plain, */*'})
        if "data" in compRes.text:
            break
        elif z == 4:
            print("Test Failed permanently at competition" + " time=" + str(z))
            print(compRes.text)
            sleep(99999999999999999)
        else:
            print("comp failed" + " time=" + str(z), compRes.text)
            sleep(2)
    else:
        sleep(10)

    # explore filters
    for z in range(0, 5):
        expRes = self.client.get(
            url=envURL + '/api/public/opportunity/search-result?opportunity=competitions&page=1&per_page=15&filters='
                         ',,,,&types=teamsize,payment,oppstatus,eligible,category',
            name='Explore-all-open',
            timeout=90, allow_redirects=False,
            headers={'sec-ch-ua': '"Not?A_Brand";v="8", "Chromium";v="108", "Brave";v="108"',
                     'Accept': 'application/json, text/plain, */*',
                     'sec-ch-ua-mobile': '?0',
                     'sec-ch-ua-platform': '"macOS"'})
        if "data" in expRes.text:
            sleep(5)
            break
        elif z == 4:
            print("Test Failed permanently at explore" + " time=" + str(z))
            print(expRes.text)
            sleep(99999999999999999)
        else:
            print("explore failed" + " time=" + str(z), compRes.text)
            sleep(2)
    else:
        sleep(5)

    # hack for explore
    for z in range(0, 5):
        postRes = self.client.get(
            url=envURL + '/api/public/opportunity/search-result?opportunity=competitions&page=1&per_page=15&filters='
                         ',,,,&types=teamsize,payment,oppstatus,eligible,category',
            name='Explore-hackathons',
            timeout=120, allow_redirects=False,
            headers={'Accept': 'application/json, text/plain, */*'})
        if "data" in postRes.text:
            sleep(5)
            break
        if z == 4:
            print("Test Failed permanently at posts" + " time=" + str(z))
            print(postRes.text)
            sleep(99999999999999999)
        else:
            print("posts failed" + " time=" + str(z), compRes.text)
            sleep(2)
    else:
        sleep(5)

    # internships in explore
    for z in range(0, 5):
        intRes = self.client.get(
            url=envURL + '/api/public/opportunity/search-result?opportunity=internships&page=1&per_page=15&filters='
                         ',,,,,,&types=oppstatus,job_type,job_timing,paid_unpaid,working_days,eligible,category',
            name='opportunity=internships',
            timeout=90, allow_redirects=False,
            headers={'Accept': 'application/json, text/plain, */*'})
        if "data" in intRes.text:
            sleep(5)
            break
        if z == 4:
            print("Test Failed permanently at internships" + " time=" + str(z))
            print(intRes.text)
            sleep(99999999999999999)
        else:
            print("internships failed" + " time=" + str(z), intRes.text)
            sleep(2)
    else:
        sleep(5)

    # homepage in explore
    for z in range(0, 5):
        homeRes = self.client.get(
            url=envURL + '/api/public/get-banners/homepage',
            name='homepage',
            timeout=90, allow_redirects=False,
            headers={'Accept': 'application/json, text/plain, */*'})
        if "data" in homeRes.text:
            sleep(5)
            break
        if z == 4:
            print("Test Failed permanently at homepage" + " time=" + str(z))
            print(homeRes.text)
            sleep(99999999999999999)
        else:
            print("homepage failed" + " time=" + str(z), homeRes.text)
            sleep(2)
    else:
        sleep(5)



from setuptools import setup, find_packages
setup(
    name='Unstop',
    version='1.0',
    license='MIT',
    author="Paras Gupta",
    author_email='paras@unstop.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='',
    keywords='Unstop',
)